# althra-core

[![PyPI - Version](https://img.shields.io/pypi/v/althra-core.svg)](https://pypi.org/project/althra-core)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/althra-core.svg)](https://pypi.org/project/althra-core)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install althra-core
```

## License

`althra-core` is distributed under the terms of the [BSD-3-Clause](https://spdx.org/licenses/BSD-3-Clause.html) license.
